/*
 * segatex SELinux tool.
 *
 * Copyright (C) 2007-2014 Shintaro Fujiwara 
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * */

#ifndef SEGATEXGETSEUSERBYNAMEPROCESS_H
#define SEGATEXGETSEUSERBYNAMEPROCESS_H

#include <QRegExp>
#include <QPushButton>
#include <QTextEdit>

#include <selinux/selinux.h>
#include "segatex_getseuserbyname.h"

class QMessageBox;
class SegatexGetseuserbyname;

class SegatexGetseuserbynameProcess: public QDialog
{
	Q_OBJECT
public:
	SegatexGetseuserbynameProcess(QWidget *parent = 0, const char *name = 0);
public slots:
	int segatex_getseuserbyname_base_process(QString linuxuser_string);
signals:
protected:
private slots:
private:
	QTextEdit *textEdit1;
	QPushButton *closeButton;
	QString linuxuser_str;
	QString seuser_str;
	QString level_str;
};

#endif
